## Explainer

This plot is modified from the approach of [warming stripes](https://en.wikipedia.org/wiki/Warming_stripes) and the general idea of presenting the overall spectrum of data within a period. On the x-axis we see the represented value (such as mean air temperature). The y-axis is only relevant for the distribution plots (filled areas) in the background. High values correspond to more frequent occurrence of these values.
The different colours correspond to different periods.

The distributions are plotted as kernel densities which is in principle a continuous and smoothed version of the histogram of all occurences. The approach leads to non-zero values below and above the actual minimum and maximum.

In the foreground, we see the stripes at the respective position of the annual value and coloured corresponding to the colorbar on the right. This color is signalling the time. Early years have more yellow colour. More recent years are blue. We see that these stripes rarely evenly mixed (which would speak against a change) but that they are often tending towards more extreme values in the recent past.

---

We suggest to select two different stations to compare the observed data. In most cases, coastal stations have less extreme conditions and show less changes compared to more inland stations.

When climate projections are added, it is noteworthy to see how the projected distributions (for the coastal area) compare to inland stations.